@@ -1,5 +1,5 @@
-# Copyright 2017-2020 Laszlo Attila Toth
-# Distributed under the terms of the GNU Lesser General Public License v3
+# Copyright 2017-2021 Laszlo Attila Toth
+# Distributed under the terms of the Apache License, Version 2.0
 
 import collections.abc
 import typing
@@ -20,6 +20,15 @@ class Node(collections.abc.MutableMapping):
     >>> c.set('root', A())
     """
 
+    SEALED_ATTR_NAME = '_sealed__'
+    _sealed__ = False
+
+    def _seal(self):
+        self._sealed__ = True
+
+    def _unseal(self):
+        self._sealed__ = False
+
     def __len__(self):
         return len(self.__dict__)
 
@@ -29,22 +38,31 @@ class Node(collections.abc.MutableMapping):
     def __setitem__(self, key, value):
         return setattr(self, key, value)
 
-    def __setattr(self, key, value):
-        if key not in self:
+    def __setattr__(self, key, value):
+        if self._sealed__ and key not in self.__dict__:
             raise KeyError(key)
         super().__setattr__(key, value)
 
     def __iter__(self):
-        return iter(self.__dict__)
+        return iter({x: y for x, y in self.__dict__.items() if x != self.SEALED_ATTR_NAME})
 
     def __delitem__(self, key):
         raise RuntimeError('Unable to delete key {}'.format(key))
 
     def __repr__(self):
-        return str(self.__dict__)
+        return str({x: y for x, y in self.__dict__.items() if x != self.SEALED_ATTR_NAME})
+
+    def __contains__(self, item):
+        return item != self.SEALED_ATTR_NAME and item in self.__dict__
 
     def load_from(self, data: dict):
-        load_node(self, data)
+        load_node(self, data, sealed=self._sealed__)
+
+    @classmethod
+    def create_from(cls, data: dict):
+        n = cls()
+        n.load_from(data)
+        return n
 
 
 class NodeList(list):
@@ -63,11 +81,11 @@ class NodeList(list):
                 self.append(node)
 
 
-def load_node(node: Node, d: dict):
+def load_node(node: Node, d: dict, *, sealed: bool = False):
     for key, value in d.items():
         if key in node and isinstance(node[key], (Node, NodeList)):
             node[key].load_from(value)
-        else:
+        elif key in node or not sealed:
             node[key] = value
 
 
