@@ -1,5 +1,5 @@
-# Copyright 2015-2017 Laszlo Attila Toth
-# Distributed under the terms of the GNU Lesser General Public License v3
+# Copyright 2015-2021 Laszlo Attila Toth
+# Distributed under the terms of the Apache License, Version 2.0
 
 import typing
 
@@ -36,3 +36,7 @@ class Plugin:
         >>
         """
         c.commands.register_class(t)
+
+    @staticmethod
+    def _register_config_dir(c: Context, d: str):
+        c.config_dir_registry.register_config_directory(d)
